@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,14 +26,8 @@
 #include "gstdvdsubparse.h"
 #include <string.h>
 
-GST_DEBUG_CATEGORY_STATIC (gst_dvd_sub_dec_debug);
-#define GST_CAT_DEFAULT (gst_dvd_sub_dec_debug)
-
 #define gst_dvd_sub_dec_parent_class parent_class
 G_DEFINE_TYPE (GstDvdSubDec, gst_dvd_sub_dec, GST_TYPE_ELEMENT);
-GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (dvdsubdec, "dvdsubdec", GST_RANK_NONE,
-    GST_TYPE_DVD_SUB_DEC, GST_DEBUG_CATEGORY_INIT (gst_dvd_sub_dec_debug,
-        "dvdsubdec", 0, "DVD subtitle decoder"));
 
 static gboolean gst_dvd_sub_dec_src_event (GstPad * srcpad, GstObject * parent,
     GstEvent * event);
@@ -67,6 +61,8 @@ static GstStaticPadTemplate subtitle_template = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_STATIC_CAPS ("subpicture/x-dvd")
     );
 
+GST_DEBUG_CATEGORY_STATIC (gst_dvd_sub_dec_debug);
+#define GST_CAT_DEFAULT (gst_dvd_sub_dec_debug)
 
 enum
 {
@@ -113,9 +109,10 @@ gst_dvd_sub_dec_class_init (GstDvdSubDecClass * klass)
 
   gobject_class->finalize = gst_dvd_sub_dec_finalize;
 
-  gst_element_class_add_static_pad_template (gstelement_class, &src_template);
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &subtitle_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&src_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&subtitle_template));
 
   gst_element_class_set_static_metadata (gstelement_class,
       "DVD subtitle decoder", "Codec/Decoder/Video",
@@ -370,7 +367,6 @@ gst_dvd_sub_dec_parse_subpic (GstDvdSubDec * dec)
                 gst_guint64_to_gdouble (GST_SECOND));
             return;
           }
-          break;
         } else {
           dec->parse_pos = NULL;
           dec->next_event_ts = GST_CLOCK_TIME_NONE;
@@ -426,7 +422,7 @@ gst_setup_palette (GstDvdSubDec * dec)
     target2_yuv->A = dec->menu_alpha[i] * 0xff / 0xf;
 
     /* If ARGB flag set, then convert YUV palette to RGB */
-    /* Using integer arithmetic */
+    /* Using integer aritmetic */
     if (dec->use_ARGB) {
       guchar C = target_yuv->Y_R - 16;
       guchar D = target_yuv->U_G - 128;
@@ -572,7 +568,7 @@ gst_dvd_sub_dec_merge_title (GstDvdSubDec * dec, GstVideoFrame * frame)
   gint hl_top, hl_bottom;
   gint last_y;
   RLE_state state;
-  guint8 *Y_data;
+  guint8 *Y_data;;
 
   GST_DEBUG_OBJECT (dec, "Merging subtitle on frame");
 
@@ -695,7 +691,8 @@ gst_send_subtitle_frame (GstDvdSubDec * dec, GstClockTime end_ts)
   }
 
   out_buf =
-      gst_buffer_new_allocate (NULL, GST_VIDEO_INFO_SIZE (&dec->info), &params);
+      gst_buffer_new_allocate (NULL, GST_VIDEO_INFO_SIZE (&dec->info),
+      &params);
   gst_video_frame_map (&frame, &dec->info, out_buf, GST_MAP_READWRITE);
 
   data = GST_VIDEO_FRAME_PLANE_DATA (&frame, 0);
@@ -894,7 +891,6 @@ gst_dvd_sub_dec_sink_setcaps (GstPad * pad, GstCaps * caps)
       GstStructure *s = gst_caps_get_structure (peer_caps, i);
       /* Check if the peer pad support ARGB format, if yes change caps */
       if (gst_structure_has_name (s, "video/x-raw")) {
-        GstCaps *downstream_caps;
         gst_caps_unref (out_caps);
         GST_DEBUG_OBJECT (dec, "trying with ARGB");
 
@@ -904,15 +900,12 @@ gst_dvd_sub_dec_sink_setcaps (GstPad * pad, GstCaps * caps)
             "height", G_TYPE_INT, dec->in_height,
             "framerate", GST_TYPE_FRACTION, 0, 1, NULL);
 
-        downstream_caps = gst_pad_peer_query_caps (dec->srcpad, NULL);
-        if (gst_caps_can_intersect (downstream_caps, out_caps)) {
-          gst_caps_unref (downstream_caps);
+        if (gst_pad_peer_query_accept_caps (dec->srcpad, out_caps)) {
           GST_DEBUG_OBJECT (dec, "peer accepted ARGB");
           /* If ARGB format then set the flag */
           dec->use_ARGB = TRUE;
           break;
         }
-        gst_caps_unref (downstream_caps);
       }
     }
     gst_caps_unref (peer_caps);
@@ -954,13 +947,10 @@ gst_dvd_sub_dec_sink_event (GstPad * pad, GstObject * parent, GstEvent * event)
       break;
     }
     case GST_EVENT_CUSTOM_DOWNSTREAM:{
+      GstClockTime ts = GST_EVENT_TIMESTAMP (event);
 
       if (gst_event_has_name (event, "application/x-gst-dvd")) {
-        const GstStructure *s = gst_event_get_structure (event);
-        GstClockTime ts = GST_CLOCK_TIME_NONE;
-
-        if (gst_structure_get_clock_time (s, "ts", &ts)
-            && GST_CLOCK_TIME_IS_VALID (ts))
+        if (GST_CLOCK_TIME_IS_VALID (ts))
           gst_dvd_sub_dec_advance_time (dec, ts);
 
         if (gst_dvd_sub_dec_handle_dvd_event (dec, event)) {
@@ -1149,12 +1139,17 @@ not_handled:
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  gboolean ret = FALSE;
+  if (!gst_element_register (plugin, "dvdsubdec", GST_RANK_NONE,
+          GST_TYPE_DVD_SUB_DEC) ||
+      !gst_element_register (plugin, "dvdsubparse", GST_RANK_NONE,
+          GST_TYPE_DVD_SUB_PARSE)) {
+    return FALSE;
+  }
 
-  ret |= GST_ELEMENT_REGISTER (dvdsubdec, plugin);
-  ret |= GST_ELEMENT_REGISTER (dvdsubparse, plugin);
+  GST_DEBUG_CATEGORY_INIT (gst_dvd_sub_dec_debug, "dvdsubdec", 0,
+      "DVD subtitle decoder");
 
-  return ret;
+  return TRUE;
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
